Index: third_party/WebKit/Source/core/dom/ActiveDOMObject.cpp |
diff --git a/third_party/WebKit/Source/core/dom/ActiveDOMObject.cpp b/third_party/WebKit/Source/core/dom/ActiveDOMObject.cpp |
index c37ee771a6af7f1dee3bae271df13a0009266bcf..21e8468338d613a99eddeef06f93a9307275e827 100644 |
--- a/third_party/WebKit/Source/core/dom/ActiveDOMObject.cpp |
+++ b/third_party/WebKit/Source/core/dom/ActiveDOMObject.cpp |
@@ -52,9 +52,9 @@ ActiveDOMObject::~ActiveDOMObject() |
ASSERT(m_suspendIfNeededCalled); |
// Oilpan: not valid to access executionContext() in the destructor. |
#if !ENABLE(OILPAN) |
- ASSERT(!executionContext() || executionContext()->isContextThread()); |
+ ASSERT(!getExecutionContext() || getExecutionContext()->isContextThread()); |
#endif |
} |
@@ -64,7 +64,7 @@ void ActiveDOMObject::suspendIfNeeded() |
ASSERT(!m_suspendIfNeededCalled); |
m_suspendIfNeededCalled = true; |
#endif |
- if (ExecutionContext* context = executionContext()) |
+ if (ExecutionContext* context = getExecutionContext()) |
context->suspendActiveDOMObjectIfNeeded(this); |
} |
@@ -52,9 +52,9 @@ ActiveDOMObject::~ActiveDOMObject() |
ASSERT(m_suspendIfNeededCalled); |
- // Oilpan: not valid to access executionContext() in the destructor. |
+ // Oilpan: not valid to access getExecutionContext() in the destructor. |
#if !ENABLE(OILPAN) |